// BookmarkDlg.h
// (c) 2003-2005 exeal

#ifndef _BOOKMARK_DLG_H_
#define _BOOKMARK_DLG_H_
#include "resource.h"
#include "Ascension\AscensionCommon.h"
#include "../Manah/Dialog.h"
#include <map>


namespace Alpha {
	class CAlphaApp;
	class CAlphaDoc;

	///	[ubN}[N] _CAO
	class CBookmarkDlg : public Manah::Windows::Controls::CLayered<
			Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_BOOKMARKS> > {
		// RXgN^
	public:
		CBookmarkDlg(CAlphaApp& app);

		// \bh
	public:
		void	UpdateList();
	protected:
		void	GetItemInfo(int iItem, CAlphaDoc** ppBuffer, Ascension::length_t& iLine) const;
		void	OnBtnDelete();

		// bZ[Wnh
	protected:
		virtual bool	OnCommand(WORD wID, WORD wNotifyCode, HWND hwndCtrl);	// WM_COMMAND
		virtual bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);		// WM_INITDIALOG
		virtual bool	OnNotify(int idCtrl, LPNMHDR lpNMHDR);					// WM_NOTIFY
		virtual void	OnOK();													// IDOK

		// f[^o
	private:
		CAlphaApp&							m_app;
		std::map<CAlphaDoc*, std::size_t>	m_bufferIndices;	// obt@ -> obt@ԍ
	};
}

#endif /* _BOOKMARK_DLG_H_ */

/* [EOF] */